@@ -1,6 +1,9 @@
 module Tins
   class Duration
+    include Comparable
+
     def initialize(seconds)
+      @original_seconds = seconds
       @days, @hours, @minutes, @seconds, @fractional_seconds =
         [ 86_400, 3600, 60, 1, 0 ].inject([ [], seconds ]) {|(r, s), d|
           if d > 0
@@ -13,6 +16,14 @@ module Tins
         }
     end
 
+    def to_f
+      @original_seconds.to_f
+    end
+
+    def <=>(other)
+      to_f <=> other.to_f
+    end
+
     def days?
       @days > 0
     end
@@ -34,12 +45,15 @@ module Tins
     end
 
     def format(template = '%d+%h:%m:%s.%f', precision: nil)
-      result = template.gsub(/%[dhms]/,
-        '%d' => @days,
-        '%h' => '%02u' % @hours,
-        '%m' => '%02u' % @minutes,
-        '%s' => '%02u' % @seconds,
-      )
+      result = template.gsub(/%[Ddhms]/) { |directive|
+        case directive
+        when '%d' then @days
+        when '%h' then '%02u' % @hours
+        when '%m' then '%02u' % @minutes
+        when '%s' then '%02u' % @seconds
+        when '%D' then format_smart
+        end
+      }
       if result.include?('%f')
         if precision
           fractional_seconds = "%.#{precision}f" % @fractional_seconds
@@ -52,6 +66,12 @@ module Tins
     end
 
     def to_s
+      format_smart
+    end
+
+    private
+
+    def format_smart
       template  = '%h:%m:%s'
       precision = nil
       if days?
