@@ -37,11 +37,16 @@ module Tins::Unit
     prefixes = prefixes(prefix)
     first_prefix = prefixes.first or
       raise ArgumentError, 'a non-empty array of prefixes is required'
-    prefix = prefixes[
-      (first_prefix.fraction ? -1 : 1) * Math.log(value) / Math.log(first_prefix.step)
-    ]
-    result = format.sub('%U', "#{prefix.name}#{unit}")
-    result %= (value / prefix.multiplier.to_f)
+    if value.zero?
+      result = format.sub('%U', unit)
+      result %= value
+    else
+      prefix = prefixes[
+        (first_prefix.fraction ? -1 : 1) * Math.log(value) / Math.log(first_prefix.step)
+      ]
+      result = format.sub('%U', "#{prefix.name}#{unit}")
+      result %= (value / prefix.multiplier.to_f)
+    end
   end
 
   class UnitParser < StringScanner
@@ -57,10 +62,12 @@ module Tins::Unit
     def initialize(source, unit, prefixes = nil)
       super source
       if prefixes
-        @unit_re = unit_re(Tins::Unit.prefixes(prefixes), unit)
+        @unit_re    = unit_re(Tins::Unit.prefixes(prefixes), unit)
+        @unit_lc_re = @unit_uc_re                                  = nil
       else
         @unit_lc_re = unit_re(Tins::Unit.prefixes(:lc), unit)
         @unit_uc_re = unit_re(Tins::Unit.prefixes(:uc), unit)
+        @unit_re    = nil
       end
       @number       = 1.0
     end
